[Libreoffice-commits] .: sw/inc

Christoph Herzog cherzog at kemper.freedesktop.org
Wed Feb 2 08:31:34 PST 2011


 sw/inc/fmtcnct.hxx  |    9 +++----
 sw/inc/fmtcntnt.hxx |    6 ++---
 sw/inc/fmtcol.hxx   |   62 ++++++++++++++++++++++++----------------------------
 sw/inc/fmtflcnt.hxx |   11 ++++-----
 sw/inc/fmtfld.hxx   |   12 +++++-----
 sw/inc/fmtfordr.hxx |    3 --
 sw/inc/fmtfsize.hxx |   44 ++++++++++++++++++------------------
 sw/inc/fmtftn.hxx   |   14 +++++------
 8 files changed, 77 insertions(+), 84 deletions(-)

New commits:
commit d51880ef7bfac56828fc7acfeb64e412fc4d84fc
Author: Christoph Herzog <rhogez at googlemail.com>
Date:   Wed Feb 2 17:23:50 2011 +0100

    Translation of German comments.

diff --git a/sw/inc/fmtcnct.hxx b/sw/inc/fmtcnct.hxx
index eab73c2..8d86dea 100644
--- a/sw/inc/fmtcnct.hxx
+++ b/sw/inc/fmtcnct.hxx
@@ -37,12 +37,11 @@
 class SwFlyFrmFmt;
 class IntlWrapper;
 
-//Verbindung (Textfluss) zwischen zwei FlyFrms
-
+// Connection (text flow) between two FlyFrms.
 class SW_DLLPUBLIC SwFmtChain: public SfxPoolItem
 {
-    SwClient aPrev,	//Vorgaenger (SwFlyFrmFmt), wenn es diesen gibt.
-             aNext; //Nachfolger (SwFlyFrmFmt), wenn es diesen gibt.
+    SwClient aPrev,	// Previous SwFlyFrmFmt (if existent).
+             aNext; // Next SwFlyFrmFmt (if existent).
 
 
 public:
@@ -51,7 +50,7 @@ public:
 
     inline SwFmtChain &operator=( const SwFmtChain& );
 
-    // "pure virtual methods" of SfxPoolItem
+    // "Pure virtual methods" of SfxPoolItem.
     virtual int             operator==( const SfxPoolItem& ) const;
     virtual SfxPoolItem*	Clone( SfxItemPool* pPool = 0 ) const;
     virtual SfxItemPresentation GetPresentation( SfxItemPresentation ePres,
diff --git a/sw/inc/fmtcntnt.hxx b/sw/inc/fmtcntnt.hxx
index 3a2c795..9c6d659 100644
--- a/sw/inc/fmtcntnt.hxx
+++ b/sw/inc/fmtcntnt.hxx
@@ -35,20 +35,20 @@
 class SwNodeIndex;
 class SwStartNode;
 
-//Cntnt, Inhalt des Frame (Header, Footer, Fly) ----
 
+// Cntnt, content of frame (header, footer, fly).
 class SW_DLLPUBLIC SwFmtCntnt: public SfxPoolItem
 {
     SwNodeIndex *pStartNode;
 
-    SwFmtCntnt &operator=( const SwFmtCntnt & ); //Kopieren verboten
+    SwFmtCntnt &operator=( const SwFmtCntnt & ); // Copying not allowed.
 
 public:
     SwFmtCntnt( const SwStartNode* pStartNode = 0 );
     SwFmtCntnt( const SwFmtCntnt &rCpy );
     ~SwFmtCntnt();
 
-    // "pure virtual methods" of SfxPoolItem
+    // "Pure virtual methods" of SfxPoolItem.
     virtual int             operator==( const SfxPoolItem& ) const;
     virtual SfxPoolItem*	Clone( SfxItemPool* pPool = 0 ) const;
 
diff --git a/sw/inc/fmtflcnt.hxx b/sw/inc/fmtflcnt.hxx
index 88f90cb..b9854c7 100644
--- a/sw/inc/fmtflcnt.hxx
+++ b/sw/inc/fmtflcnt.hxx
@@ -33,25 +33,24 @@
 
 class SwFrmFmt;
 class SwTxtFlyCnt;
-// ATT_FLYCNT *******************************************************
+// ATT_FLYCNT
 
 class SwFmtFlyCnt : public SfxPoolItem
 {
     friend class SwTxtFlyCnt;
-    SwTxtFlyCnt* pTxtAttr;		// mein TextAttribut
-    SwFrmFmt* pFmt;				// mein Fly/DrawFrame-Format
+    SwTxtFlyCnt* pTxtAttr;
+    SwFrmFmt* pFmt;	// My Fly/DrawFrame-format.
     // protected CopyCtor
     SwFmtFlyCnt& operator=(const SwFmtFlyCnt& rFlyCnt);
 
 public:
     SwFmtFlyCnt( SwFrmFmt *pFrmFmt );
-    // "pure virtual methods" of SfxPoolItem
+    // "Pure virtual methods" of SfxPoolItem.
     virtual int             operator==( const SfxPoolItem& ) const;
     virtual SfxPoolItem*	Clone( SfxItemPool* pPool = 0 ) const;
 
     inline SwFrmFmt *GetFrmFmt() const { return pFmt; }
-    // fuer Undo: loesche "logisch" das FlyFrmFormat, wird sich im
-    //          Undo-Object gemerkt.
+    // For Undo: delete the FlyFrmFormat "logically"; it is kept in Undo-object.
     inline void SetFlyFmt( SwFrmFmt* pNew = 0 )   { pFmt = pNew; }
 
     const SwTxtFlyCnt *GetTxtFlyCnt() const	{ return pTxtAttr; }
diff --git a/sw/inc/fmtfld.hxx b/sw/inc/fmtfld.hxx
index 66e2893..68df10d 100644
--- a/sw/inc/fmtfld.hxx
+++ b/sw/inc/fmtfld.hxx
@@ -39,25 +39,25 @@ class SwField;
 class SwTxtFld;
 class SwView;
 
-// ATT_FLD ***********************************
+// ATT_FLD
 class SW_DLLPUBLIC SwFmtFld : public SfxPoolItem, public SwClient, public SfxBroadcaster
 {
     friend class SwTxtFld;
     friend void _InitCore();
 
     SwField *pField;
-    SwTxtFld* pTxtAttr;		// mein TextAttribut
+    SwTxtFld* pTxtAttr;
 
-    SwFmtFld();				// das default-Attibut
+    SwFmtFld(); // Default attibute.
 
-    // protected CopyCtor
+    // Protected CopyCtor.
     // @@@ copy construction allowed, but copy assignment is not? @@@
     SwFmtFld& operator=(const SwFmtFld& rFld);
 
 public:
     TYPEINFO();
 
-    // single argument constructors shall be explicit.
+    // Single argument constructors shall be explicit.
     explicit SwFmtFld( const SwField &rFld );
 
     // @@@ copy construction allowed, but copy assignment is not? @@@
@@ -65,7 +65,7 @@ public:
 
     virtual ~SwFmtFld();
 
-    // "pure virtual methods" of SfxPoolItem
+    // "Pure virtual methods" of SfxPoolItem.
     virtual int             operator==( const SfxPoolItem& ) const;
     virtual SfxPoolItem*	Clone( SfxItemPool* pPool = 0 ) const;
 
diff --git a/sw/inc/fmtfordr.hxx b/sw/inc/fmtfordr.hxx
index 002d126..d0a92e3 100644
--- a/sw/inc/fmtfordr.hxx
+++ b/sw/inc/fmtfordr.hxx
@@ -32,7 +32,6 @@
 #include <hintids.hxx>
 #include <format.hxx>
 
-//Die FillOrder ---------------------------------
 
 enum SwFillOrder
 {
@@ -50,7 +49,7 @@ public:
     SwFmtFillOrder( SwFillOrder = ATT_TOP_DOWN );
     inline SwFmtFillOrder &operator=( const SwFmtFillOrder &rCpy );
 
-    // "pure virtual methods" of SfxPoolItem
+    // "Pure virtual methods" of SfxPoolItem.
     virtual SfxPoolItem*	Clone( SfxItemPool *pPool = 0 ) const;
     virtual USHORT			GetValueCount() const;
 
diff --git a/sw/inc/fmtfsize.hxx b/sw/inc/fmtfsize.hxx
index fd8be4d..3484a85 100644
--- a/sw/inc/fmtfsize.hxx
+++ b/sw/inc/fmtfsize.hxx
@@ -37,15 +37,14 @@
 
 class IntlWrapper;
 
-//Die Framesize ---------------------------------
+//Frame size.
 
 enum SwFrmSize
 {
-    ATT_VAR_SIZE,		//Frm ist in der Var-Richtung variabel
-    ATT_FIX_SIZE,		//Frm ist in der Var-Richtung unbeweglich
-    ATT_MIN_SIZE		//Der Wert in der Var-Richtung beschreibt eine
-                        //Minimalgroesse, die nicht unter- wohl aber
-                        //ueberschritten werden kann.
+    ATT_VAR_SIZE,		// Frame is variable in Var-direction.
+    ATT_FIX_SIZE,		// Frame cannot be moved in Var-direction.
+    ATT_MIN_SIZE		// Value in Var-direction gives minimum
+                        // (can be exceeded but not be less).
 };
 
 class SW_DLLPUBLIC SwFmtFrmSize: public SfxPoolItem
@@ -53,27 +52,28 @@ class SW_DLLPUBLIC SwFmtFrmSize: public SfxPoolItem
     Size	  aSize;
     SwFrmSize eFrmHeightType;
     SwFrmSize eFrmWidthType;
-    BYTE 	  nWidthPercent;	//Fuer Tabellen kann die Breite in Prozent
-    BYTE	  nHeightPercent;	//angegeben sein.
-                                //Fuer Rahmen koennen Hoehe und/oder Breite
-                                //in Prozent angegeben sein. Wenn nur eine
-                                //der Angaben in Prozent angeben ist, kann
-                                //durch den ausgezeichneten Wert 0xFF in der
-                                //anderen Prozentangabe bestimmt werden, das
-                                //sich diese Richtung proportional zur anderen
-                                //verhaelt. Basis fuer die Umrechnung sind fuer
-                                //diesen Fall die Angaben in der Size.
-                                //Die Prozentwerte beziehen sich immer auf die
-                                //Umgebung in der das Objekt steht (PrtArea)
-                                //Auf die Bildschirmbreite abzueglich Raender
-                                //in der BrowseView wenn die Umgebung die Seite
-                                //ist.
+    BYTE 	  nWidthPercent;
+    BYTE	  nHeightPercent;
+
+    // For tables: width can be given in percent.
+
+    // For frames: height and/or width may be given in percent.
+    // If only one of these percentage values is given, the value 0xFF
+    // used instead of the missing percentage value indicates this side
+    // being proportional to the given one.
+    // The calculation in this case is based upon the values in Size.
+    // Percentages are always related to the environment in which
+    // the object is placed (PrtArea) and to the screen width
+    // minus borders in BrowseView if the environment is the page.
+
+
+
 public:
     SwFmtFrmSize( SwFrmSize eSize = ATT_VAR_SIZE,
                   SwTwips nWidth = 0, SwTwips nHeight = 0 );
     SwFmtFrmSize& operator=( const SwFmtFrmSize& rCpy );
 
-    // "pure virtual methods" of SfxPoolItem
+    // "Pure virtual methods" of SfxPoolItem.
     virtual int             operator==( const SfxPoolItem& ) const;
     virtual SfxPoolItem*	Clone( SfxItemPool *pPool = 0 ) const;
     virtual SfxItemPresentation GetPresentation( SfxItemPresentation ePres,
diff --git a/sw/inc/fmtftn.hxx b/sw/inc/fmtftn.hxx
index 2f947c4..1e6d6cb 100644
--- a/sw/inc/fmtftn.hxx
+++ b/sw/inc/fmtftn.hxx
@@ -35,17 +35,17 @@
 class SwDoc;
 class SwTxtFtn;
 
-// ATT_FTN **********************************************************
+// ATT_FTN
 
 class SW_DLLPUBLIC SwFmtFtn: public SfxPoolItem
 {
     friend class SwTxtFtn;
-    SwTxtFtn* pTxtAttr;		//my TextAttribute
-    String  aNumber;		//user-defined 'Number'
-    USHORT  nNumber;		//automatic numbering
-    bool    m_bEndNote;     // is it an End note?
+    SwTxtFtn* pTxtAttr;		// My TextAttribute.
+    String  aNumber;		// User-defined 'Number'.
+    USHORT  nNumber;		// Automatic numbering.
+    bool    m_bEndNote;     // Is it an End note?
 
-    // protected CopyCtor
+    // Protected CopyCtor.
     SwFmtFtn& operator=(const SwFmtFtn& rFtn);
     SwFmtFtn( const SwFmtFtn& );
 
@@ -53,7 +53,7 @@ public:
     SwFmtFtn( bool bEndNote = false );
     virtual ~SwFmtFtn();
 
-    // "pure virtual methods" of SfxPoolItem
+    // "Pure virtual methods" of SfxPoolItem.
     virtual int             operator==( const SfxPoolItem& ) const;
     virtual SfxPoolItem*	Clone( SfxItemPool* pPool = 0 ) const;
 


More information about the Libreoffice-commits mailing list
diff --git a/sw/inc/fmtcol.hxx b/sw/inc/fmtcol.hxx
index ad86881..e47efd1 100644
--- a/sw/inc/fmtcol.hxx
+++ b/sw/inc/fmtcol.hxx
@@ -31,9 +31,9 @@
 #include <svl/svarray.hxx>
 #include "swdllapi.h"
 #include <format.hxx>
-#include <swtypes.hxx>		// fuer MAXLEVEL
+#include <swtypes.hxx> // For MAXLEVEL.
 
-class SwDoc;		// fuer friend
+class SwDoc; // For friend.
 
 class SwFmtColl : public SwFmt
 {
@@ -51,7 +51,8 @@ protected:
     { SetAuto( FALSE ); }
 
 private:
-    // erstmal wird nicht kopiert und nicht zugewiesen
+
+    // For now don't copy and don't assign.
     SwFmtColl(const SwFmtColl & );
     const SwFmtColl &operator=(const SwFmtColl &);
 };
@@ -92,10 +93,10 @@ protected:
     { pNextTxtFmtColl = this; }
 public:
 
-    // zum "abfischen" von UL-/LR-/FontHeight Aenderungen
+    // To get UL- / LR- / FontHeight-changes.
     virtual void Modify( SfxPoolItem*, SfxPoolItem* );
 
-    TYPEINFO();		//Bereits in Basisklasse Client drin.
+    TYPEINFO();	// Already in base class Client.
 
     inline void SetNextTxtFmtColl(SwTxtFmtColl& rNext);
     SwTxtFmtColl& GetNextTxtFmtColl() const { return *pNextTxtFmtColl; }
@@ -112,13 +113,13 @@ public:
     void AssignToListLevelOfOutlineStyle(const int nAssignedListLevel);
     void DeleteAssignmentToListLevelOfOutlineStyle();
 
-    // override to recognize changes on the <SwNumRuleItem> and register/unregister
-    // the paragragh style at the corresponding <SwNumRule> instance
+    // Override to recognize changes on the <SwNumRuleItem> and register/unregister
+    // the paragragh style at the corresponding <SwNumRule> instance.
     virtual BOOL SetFmtAttr( const SfxPoolItem& rAttr );
     virtual BOOL SetFmtAttr( const SfxItemSet& rSet );
     virtual BOOL ResetFmtAttr( USHORT nWhich1, USHORT nWhich2 = 0 );
 
-    // override <ResetAllFmtAttr()> to stay assigned to list level of outline style
+    // Override <ResetAllFmtAttr()> to stay assigned to list level of outline style.
     virtual USHORT ResetAllFmtAttr();
 
     inline bool StayAssignedToListLevelOfOutlineStyle() const
@@ -129,12 +130,10 @@ public:
     bool AreListLevelIndentsApplicable() const;
 
 /*
- wird die Funktionalitaet von Zeichenvorlagen an Absatzvorlagen
- ueberhaupt benoetigt ??
-
- Wenn, ja dann muessen im TextNode und hier in der TxtCollection ein 2.
- Attset fuer die Char-Attribute angelegt werden; damit die Vererbung
- und der Zugriff auf die gesetzen Attribute richtig funktioniert!!
+ Is the functionality of character styles at paragraph styles needed?
+ If so, a second Attset for char-attributes has to be created
+ in TextNode and here in TxtCollection in order to make both
+ the inheritance of and the access to set attributes function correctly!
 
     virtual BOOL SetDerivedFrom( SwFmtColl* pDerFrom = 0 );
 
@@ -142,15 +141,15 @@ public:
     inline BOOL IsCharFmtSet() const;
     void SetCharFmt(SwCharFmt *);
     void ResetCharFmt();
-inline BOOL SwTxtFmtColl::IsCharFmtSet() const
-{
-    return aCharDepend.GetRegisteredIn() ? TRUE : FALSE;
-}
-inline SwCharFmt* SwTxtFmtColl::GetCharFmt() const
-{
-    return (SwCharFmt*)aCharDepend.GetRegisteredIn();
-}
---------------------------------------------------*/
+    inline BOOL SwTxtFmtColl::IsCharFmtSet() const
+    {
+        return aCharDepend.GetRegisteredIn() ? TRUE : FALSE;
+    }
+    inline SwCharFmt* SwTxtFmtColl::GetCharFmt() const
+    {
+        return (SwCharFmt*)aCharDepend.GetRegisteredIn();
+    }
+*/
 };
 
 typedef SwTxtFmtColl* SwTxtFmtCollPtr;
@@ -173,15 +172,14 @@ protected:
     {}
 
 public:
-    TYPEINFO();		//Bereits in Basisklasse Client drin.
+    TYPEINFO();	// Already in base class Client.
 };
 
 typedef SwGrfFmtColl* SwGrfFmtCollPtr;
 SV_DECL_PTRARR(SwGrfFmtColls,SwGrfFmtCollPtr,2,4)
 
-//FEATURE::CONDCOLL
-// --------- Bedingte Vorlagen -------------------------------
-
+// FEATURE::CONDCOLL
+// Conditional styles.
 enum Master_CollConditions
 {
     PARA_IN_LIST		= 0x0001,
@@ -208,7 +206,7 @@ class SW_DLLPUBLIC SwCollCondition : public SwClient
     } aSubCondition;
 
 public:
-    TYPEINFO();		//Bereits in Basisklasse Client drin.
+    TYPEINFO();	// Already in base class Client.
 
     SwCollCondition( SwTxtFmtColl* pColl, ULONG nMasterCond,
                     ULONG nSubCond = 0 );
@@ -255,7 +253,7 @@ protected:
     {}
 
 public:
-    TYPEINFO();		//Bereits in Basisklasse Client drin.
+    TYPEINFO();	// Already in base class Client.
 
     virtual ~SwConditionTxtFmtColl();
 
@@ -267,10 +265,8 @@ public:
     void SetConditions( const SwFmtCollConditions& );
 };
 
-//FEATURE::CONDCOLL
-
-// ------------- Inline Implementierungen --------------------
-
+// FEATURE::CONDCOLL
+// Inline implementations.
 inline void SwTxtFmtColl::SetNextTxtFmtColl( SwTxtFmtColl& rNext )
 {
     pNextTxtFmtColl = &rNext;